==> ro-2.15.1.zip: ro/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Mergi la conținut';
$GLOBALS['__l10n']['To menu'] = 'Mergi la meniu';
$GLOBALS['__l10n']['To search'] = 'Mergi la căutare';
$GLOBALS['__l10n']['By'] = 'De';
$GLOBALS['__l10n']['by'] = 'de';
$GLOBALS['__l10n']['on'] = 'activat';
$GLOBALS['__l10n']['On'] = 'Activat';
$GLOBALS['__l10n']['Continue reading'] = 'Citește în continuare';
$GLOBALS['__l10n']['no comments'] = 'niciun comentariu';
$GLOBALS['__l10n']['one comment'] = 'un comentariu';
$GLOBALS['__l10n']['%d comments'] = '%d comentarii';
$GLOBALS['__l10n']['no trackbacks'] = 'fără trackback';
$GLOBALS['__l10n']['one trackback'] = 'un trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackback-uri';
$GLOBALS['__l10n']['no attachments'] = 'niciun atașament';
$GLOBALS['__l10n']['one attachment'] = 'un atașament';
$GLOBALS['__l10n']['%d attachments'] = '%d atașamente';
$GLOBALS['__l10n']['previous entries'] = 'postări anterioare';
$GLOBALS['__l10n']['page'] = 'pagină';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'următoarele postări';
$GLOBALS['__l10n']['Search'] = 'Căutare';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Căutarea dvs după <em>%1$s</em> nu are rezultate.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Căutate dvs după <em>%1$s</em> are următorul <strong>%2$s</strong> rezultat';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Căutate dvs după <em>%1$s</em> are următoarele <strong>%2$s</strong> rezultate';
$GLOBALS['__l10n']['Home'] = 'Pagină de pornire';
$GLOBALS['__l10n']['All keywords'] = 'Toate cuvintele-cheie';
$GLOBALS['__l10n']['Best of me'] = 'Cel mai bun din mine';
$GLOBALS['__l10n']['Languages'] = 'Limbi';
$GLOBALS['__l10n']['Categories'] = 'Categorii';
$GLOBALS['__l10n']['Subcategories'] = 'Subcategorii';
$GLOBALS['__l10n']['Archives'] = 'Arhive';
$GLOBALS['__l10n']['Links'] = 'Legături';
$GLOBALS['__l10n']['Subscribe'] = 'Abonare';
$GLOBALS['__l10n']['Entries feed'] = 'Abonament de postări';
$GLOBALS['__l10n']['Comments feed'] = 'Abonament de comentarii';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Abonamentul Atom al acestui blog';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Abonamentul Atom al postărilor din această categorie';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Abonamentul Atom al comentarilor din această categorie';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Abonamentul comentarilor postării acesteia';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Abonamentul Atom de comentarii al acestei postări';
$GLOBALS['__l10n']['Attachments'] = 'Atașamente';
$GLOBALS['__l10n']['Permalink'] = 'Permalink';
$GLOBALS['__l10n']['Comments'] = 'Comentarii';
$GLOBALS['__l10n']['Your comment'] = 'Comentariul dvs';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Comentariul dvs a fost publicat.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Comentariul dvs a fost trimis și va fi revizuit înainte de publicare.';
$GLOBALS['__l10n']['Add a comment'] = 'Adaugă un comentariu';
$GLOBALS['__l10n']['Name or nickname'] = 'Nume sau poreclă';
$GLOBALS['__l10n']['Email address'] = 'Adresă de contact';
$GLOBALS['__l10n']['Website'] = 'Sit web';
$GLOBALS['__l10n']['optional'] = 'opțional';
$GLOBALS['__l10n']['Comment'] = 'Comentariu';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'Codul html este afișat ca text iar adresele web sunt procesate automat.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Ține-mă minte pe acest blog.';
$GLOBALS['__l10n']['preview'] = 'previzualizare';
$GLOBALS['__l10n']['send'] = 'trimite';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Și ei au postat pe același subiect';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'Trebuie să specifici un nume de autor';
$GLOBALS['__l10n']['You must provide a comment'] = 'Trebuie să scrii un comentariu';
$GLOBALS['__l10n']['Email address is not valid'] = 'Adresa de contact nu este valabilă';
$GLOBALS['__l10n']['Document not found'] = 'Documentul nu a fost găsit';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Documentul pe care îl căutați nu există';
$GLOBALS['__l10n']['Powered by %s'] = 'Creat de %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Abonează-te la';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Ce este un abonament RSS?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Abonamentul RSS este un sumar de blog gratuit. Oferă conținut (fie postări sau comentarii) sau un sumar de conținut, împreună cu legături web către versiunea completă a conținutului respectiv, și alte metadate. Ultimele conținuturi publicate pot fi citite de către <a href="http://en.wikipedia.org/wiki/Aggregator">abonatorul</a> dvs favorit.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Pur și simplu copiați următoarea legătură web în abonatorul dvs';
$GLOBALS['__l10n']['Password needed'] = 'Parola este necesară';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Trebuie să inserați o parolă pentru a accesa această zonă.';
$GLOBALS['__l10n']['Password:'] = 'Parolă:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Trebuie să furnizați o adresă email validă.';
$GLOBALS['__l10n']['Read'] = 'Citeşte';
$GLOBALS['__l10n']['in'] = '';
$GLOBALS['__l10n']['In'] = '';
$GLOBALS['__l10n']['Page top'] = '';
$GLOBALS['__l10n']['toDay'] = '';
$GLOBALS['__l10n']['FromDay'] = '';
$GLOBALS['__l10n']['By category'] = '';
$GLOBALS['__l10n']['By date'] = '';
$GLOBALS['__l10n']['By tag'] = '';
$GLOBALS['__l10n']['Blog menu'] = 'Mergi la meniu';
$GLOBALS['__l10n']['Etra menu'] = 'Mergi la meniu';
$GLOBALS['__l10n']['Blog info'] = '';

==> ro-2.17.zip: ro/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['%d attachments'] = '%d atașamente';
$GLOBALS['__l10n']['%d comments'] = '%d comentarii';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackback-uri';
$GLOBALS['__l10n']['%s reactions'] = '';
$GLOBALS['__l10n']['Access to content'] = 'Mergi la conținut';
$GLOBALS['__l10n']['Add a comment'] = 'Adaugă un comentariu';
$GLOBALS['__l10n']['Add ping'] = '';
$GLOBALS['__l10n']['Additionnal style directives'] = '';
$GLOBALS['__l10n']['All keywords'] = 'Toate cuvintele-cheie';
$GLOBALS['__l10n']['Archives'] = 'Arhive';
$GLOBALS['__l10n']['Attachments'] = 'Atașamente';
$GLOBALS['__l10n']['Best of me'] = 'Cel mai bun din mine';
$GLOBALS['__l10n']['Blog info'] = '';
$GLOBALS['__l10n']['Blog menu'] = 'Mergi la meniu';
$GLOBALS['__l10n']['By'] = 'De';
$GLOBALS['__l10n']['By category'] = '';
$GLOBALS['__l10n']['By date'] = '';
$GLOBALS['__l10n']['By tag'] = '';
$GLOBALS['__l10n']['Categories'] = 'Categorii';
$GLOBALS['__l10n']['Comment'] = 'Comentariu';
$GLOBALS['__l10n']['Comments'] = 'Comentarii';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['Comments feed'] = 'Abonament de comentarii';
$GLOBALS['__l10n']['Continue reading'] = 'Citește în continuare';
$GLOBALS['__l10n']['Document not found'] = 'Documentul nu a fost găsit';
$GLOBALS['__l10n']['Email address'] = 'Adresă de contact';
$GLOBALS['__l10n']['Email address is not valid'] = 'Adresa de contact nu este valabilă';
$GLOBALS['__l10n']['Entries feed'] = 'Abonament de postări';
$GLOBALS['__l10n']['Explore archives'] = '';
$GLOBALS['__l10n']['Extra menu'] = 'Mergi la meniu';
$GLOBALS['__l10n']['From'] = '';
$GLOBALS['__l10n']['FromDay'] = '';
$GLOBALS['__l10n']['Go to homepage'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'Codul html este afișat ca text iar adresele web sunt procesate automat.';
$GLOBALS['__l10n']['Home'] = 'Pagină de pornire';
$GLOBALS['__l10n']['In'] = '';
$GLOBALS['__l10n']['Languages'] = 'Limbi';
$GLOBALS['__l10n']['Links'] = 'Legături';
$GLOBALS['__l10n']['Name or nickname'] = 'Nume sau poreclă';
$GLOBALS['__l10n']['Next entry:'] = 'următoarele postări';
$GLOBALS['__l10n']['On'] = 'Activat';
$GLOBALS['__l10n']['Page top'] = '';
$GLOBALS['__l10n']['Password needed'] = 'Parola este necesară';
$GLOBALS['__l10n']['Password:'] = 'Parolă:';
$GLOBALS['__l10n']['Permalink'] = 'Permalink';
$GLOBALS['__l10n']['Powered by %s'] = 'Creat de %s';
$GLOBALS['__l10n']['Preview'] = 'previzualizare';
$GLOBALS['__l10n']['Previous entry:'] = 'postări anterioare';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Abonamentul RSS este un sumar de blog gratuit. Oferă conținut (fie postări sau comentarii) sau un sumar de conținut, împreună cu legături web către versiunea completă a conținutului respectiv, și alte metadate. Ultimele conținuturi publicate pot fi citite de către <a href="http://en.wikipedia.org/wiki/Aggregator">abonatorul</a> dvs favorit.';
$GLOBALS['__l10n']['Read'] = 'Citeşte';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Ține-mă minte pe acest blog.';
$GLOBALS['__l10n']['Required field'] = '';
$GLOBALS['__l10n']['Search'] = 'Căutare';
$GLOBALS['__l10n']['Send'] = '';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Pur și simplu copiați următoarea legătură web în abonatorul dvs';
$GLOBALS['__l10n']['Subcategories'] = 'Subcategorii';
$GLOBALS['__l10n']['Subscribe'] = 'Abonare';
$GLOBALS['__l10n']['Subscribe to'] = 'Abonează-te la';
$GLOBALS['__l10n']['Suggestions:'] = '';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Documentul pe care îl căutați nu există';
$GLOBALS['__l10n']['The list of recents posts is available'] = '';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Și ei au postat pe același subiect';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Abonamentul Atom al acestui blog';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Abonamentul Atom al comentarilor din această categorie';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Abonamentul Atom al postărilor din această categorie';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Abonamentul Atom de comentarii al acestei postări';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Abonamentul comentarilor postării acesteia';
$GLOBALS['__l10n']['To content'] = 'Mergi la conținut';
$GLOBALS['__l10n']['To menu'] = 'Mergi la meniu';
$GLOBALS['__l10n']['To search'] = 'Mergi la căutare';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback URL';
$GLOBALS['__l10n']['URL you\'ve tried has typos, or the page has been deleted or moved.'] = '';
$GLOBALS['__l10n']['Use search form'] = '';
$GLOBALS['__l10n']['Website'] = 'Sit web';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Ce este un abonament RSS?';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Trebuie să inserați o parolă pentru a accesa această zonă.';
$GLOBALS['__l10n']['You must provide a comment'] = 'Trebuie să scrii un comentariu';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Trebuie să furnizați o adresă email validă.';
$GLOBALS['__l10n']['You must provide an author name'] = 'Trebuie să specifici un nume de autor';
$GLOBALS['__l10n']['Your comment'] = 'Comentariul dvs';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Comentariul dvs a fost publicat.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Comentariul dvs a fost trimis și va fi revizuit înainte de publicare.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Căutate dvs după <em>%1$s</em> are următorul <strong>%2$s</strong> rezultat';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Căutate dvs după <em>%1$s</em> are următoarele <strong>%2$s</strong> rezultate';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Căutarea dvs după <em>%1$s</em> nu are rezultate.';
$GLOBALS['__l10n']['by'] = 'de';
$GLOBALS['__l10n']['here'] = '';
$GLOBALS['__l10n']['in'] = '';
$GLOBALS['__l10n']['next entries'] = 'următoarele postări';
$GLOBALS['__l10n']['no attachments'] = 'niciun atașament';
$GLOBALS['__l10n']['no comments'] = 'niciun comentariu';
$GLOBALS['__l10n']['no reactions'] = '';
$GLOBALS['__l10n']['no trackbacks'] = 'fără trackback';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['on'] = 'activat';
$GLOBALS['__l10n']['one attachment'] = 'un atașament';
$GLOBALS['__l10n']['one comment'] = 'un comentariu';
$GLOBALS['__l10n']['one reaction'] = 'Citește în continuare';
$GLOBALS['__l10n']['one trackback'] = 'un trackback';
$GLOBALS['__l10n']['optional'] = 'opțional';
$GLOBALS['__l10n']['page'] = 'pagină';
$GLOBALS['__l10n']['preview'] = 'previzualizare';
$GLOBALS['__l10n']['previous entries'] = 'postări anterioare';
$GLOBALS['__l10n']['reactions'] = '';
$GLOBALS['__l10n']['send'] = 'trimite';
$GLOBALS['__l10n']['toDay'] = '';
